@@ -20,8 +20,8 @@ class ByteMatrix : public Matrix<int8_t>
 public:
 	ByteMatrix() = default;
 	ByteMatrix(int width, int height, int8_t val = 0) : Matrix<int8_t>(width, height, val) {}
-	ByteMatrix(ByteMatrix&&) = default;
-	ByteMatrix& operator=(ByteMatrix&&) = default;
+	ByteMatrix(ByteMatrix&&) noexcept = default;
+	ByteMatrix& operator=(ByteMatrix&&) noexcept = default;
 };
 
 } // ZXing
