@@ -13,7 +13,7 @@
 
 namespace ZXing {
 
-class DecodeHints;
+class ReaderOptions;
 
 namespace OneD {
 
@@ -22,8 +22,8 @@ class RowReader;
 class Reader : public ZXing::Reader
 {
 public:
-	explicit Reader(const DecodeHints& hints);
-    ~Reader() override;
+	explicit Reader(const ReaderOptions& opts);
+	~Reader() override;
 
 	Result decode(const BinaryBitmap& image) const override;
 	Results decode(const BinaryBitmap& image, int maxSymbols) const override;
