@@ -35,7 +35,7 @@ public:
 	{
 		std::shared_ptr<const BitMatrix> bits;
 		std::list<std::array<Nullable<ResultPoint>, 8>> points;
-		int rotation;
+		int rotation = -1;
 	};
 
 	static Result Detect(const BinaryBitmap& image, bool multiple, bool tryRotate);
