@@ -5,8 +5,6 @@
 
 #pragma once
 
-#define ZX_USE_UTF8 1 // see Result.h
-
 #include "ReadBarcode.h"
 
 #include <opencv2/opencv.hpp>
@@ -28,9 +26,9 @@ inline ZXing::ImageView ImageViewFromMat(const cv::Mat& image)
 	return {image.data, image.cols, image.rows, fmt};
 }
 
-inline ZXing::Results ReadBarcodes(const cv::Mat& image, const ZXing::DecodeHints& hints = {})
+inline ZXing::Results ReadBarcodes(const cv::Mat& image, const ZXing::ReaderOptions& options = {})
 {
-	return ZXing::ReadBarcodes(ImageViewFromMat(image), hints);
+	return ZXing::ReadBarcodes(ImageViewFromMat(image), options);
 }
 
 inline void DrawResult(cv::Mat& img, ZXing::Result res)
